% =============================================================================
%
% solve_piezo_VEH_1.m
%
% CBP 14-02-21
% From Dhakar et al, (2013)
%
% =============================================================================

global kk mm ddamp driveAmp driveFrequ endstop

% parameters ------------------------------------

% piezo beam
printf("Params for Piezo beam\n");
E1 = 6.6e10
l1 = 31.88e-3
t1 = 0.51e-3
w1 = 6.4e-3 
I1 = w1*t1^3/12
k1 = 0.972*3*E1*I1/l1^3
m1 = l1*w1*t1*7800;
m1 = 0.23*m1
f1 = sqrt(k1/(m1))/(2*pi);
printf("frequ of piezo beam = %f\n",f1);

%piezo plus proof mass
printf("\nParams for Piezo beam + proof mass\n");
m2 = m1 + 0.72E-3
k2 = k1
f2 = sqrt(k2/(m2))/(2*pi);
printf("frequ of piezo beam plus proof mass = %f\n",f2);

% plastic beam plus proof mass
printf("\nParams for Piezo + plastic beam + proof mass\n");
E2 = 500e6
l2 = 21.33e-3
t2 = 0.55e-3
w2 = 13.2e-3 
I2 = w2*t2^3/12
k2a = 0.972*3*E2*I2/l2^3
m2a = l2*w2*t2*1390;

k3 = k1*k2a/(k1 + k2a)
m3 = 0.72E-3 + m1 + 0.23*m2a
f3 = sqrt(k3/(m3))/(2*pi)
printf("frequ of composite beam plus proof mass = %f\n\n",f3);

printf("Input 1 for simple piezo beam\n");
printf("Input 2 for piezo beam plus proof mass\n");
printf("Input 3 for composite beam plus proof mass\n");
printf("Input 4 for composite beam plus proof mass plus end stop\n");
choice = input('  ');
if (choice == 1)
  mm = m1;
  kk = k1;
  endstop = 0;  
elseif (choice == 2)
  mm = m2;
  kk = k2;
  endstop = 0;  
elseif (choice == 3)
  mm = m3;
  kk = k3;
  endstop = 0;
  elseif (choice == 4)
  mm = m3;
  kk = k3;  
  endstop = 1;
endif

printf("Chosen mass is %f, chosen stiffness is %f\n",mm,kk);
ff = sqrt(kk/(mm))/(2*pi);
printf("Resonant frequency is %f\n",ff);
% scaling from graphs in the paper
dispToVolts = 3.25/8.0;

tstart = 0;
tend = input('Input end time');
ddamp = 0.005
driveAmp = 10
driveFrequ = input('I/p drive frequ (Hz) ')
xinit = [1e-6,0];

options = odeset('RelTol',1e-6,'AbsTol',1e-6,'InitialStep',tend/1e5,'MaxStep',tend/1e5);

[t,y] = ode45(@rhs_piezo_VEH_1,[tstart,tend],xinit,options);

figure(1);
plot(t,1000*y(:,1));
title('displacement vs. time');


